<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "有効期限が切れています。",
"Couldn't send mail to following users: %s " => "次のユーザーにメールを送信できませんでした: %s",
"Turned on maintenance mode" => "メンテナンスモードがオンになりました",
"Turned off maintenance mode" => "メンテナンスモードがオフになりました",
"Updated database" => "データベース更新完了",
"Checked database schema update" => "指定データベースのスキーマを更新",
"Disabled incompatible apps: %s" => "無効化された非互換アプリ：%s",
"No image or file provided" => "画像もしくはファイルが提供されていません",
"Unknown filetype" => "不明なファイルタイプ",
"Invalid image" => "無効な画像",
"No temporary profile picture available, try again" => "一時的なプロファイル用画像が利用できません。もう一度試してください",
"No crop data provided" => "クロップデータは提供されません",
"Sunday" => "日",
"Monday" => "月",
"Tuesday" => "火",
"Wednesday" => "水",
"Thursday" => "木",
"Friday" => "金",
"Saturday" => "土",
"January" => "1月",
"February" => "2月",
"March" => "3月",
"April" => "4月",
"May" => "5月",
"June" => "6月",
"July" => "7月",
"August" => "8月",
"September" => "9月",
"October" => "10月",
"November" => "11月",
"December" => "12月",
"Settings" => "設定",
"File" => "ファイル",
"Folder" => "フォルダー",
"Image" => "画像",
"Audio" => "オーディオ",
"Saving..." => "保存中...",
"seconds ago" => "数秒前",
"_%n minute ago_::_%n minutes ago_" => array("%n 分前"),
"_%n hour ago_::_%n hours ago_" => array("%n 時間前"),
"today" => "今日",
"yesterday" => "昨日",
"_%n day ago_::_%n days ago_" => array("%n日前"),
"last month" => "1ヶ月前",
"_%n month ago_::_%n months ago_" => array("%nヶ月前"),
"last year" => "1年前",
"years ago" => "数年前",
"Couldn't send reset email. Please contact your administrator." => "リセットメールを送信できませんでした。管理者に問い合わせてください。",
"The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." => "パスワードをリセットする、このリンクをクリックするとメールを送信します。しばらく経ってもメールが届かなかった場合は、スパム/ジャンクフォルダを確認してください。<br>それでも見つからなかった場合は、管理者に問合せてください。",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" => "ファイルが暗号化されています。リカバリーキーが有効でない場合は、パスワードをリセットした後にあなたのデータを元に戻す方法はありません。<br />どういうことか分からない場合は、操作を継続する前に管理者に連絡してください。<br />続けてよろしいでしょうか?",
"I know what I'm doing" => "どういう操作をしているか理解しています",
"Reset password" => "パスワードをリセット",
"Password can not be changed. Please contact your administrator." => "パスワードは変更できません。管理者に問い合わせてください。",
"Yes" => "はい",
"No" => "いいえ",
"Choose" => "選択",
"Error loading file picker template: {error}" => "ファイル選択テンプレートの読み込みエラー: {error}",
"Ok" => "OK",
"Error loading message template: {error}" => "メッセージテンプレートの読み込みエラー: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} ファイルが競合"),
"One file conflict" => "1ファイルが競合",
"New Files" => "新しいファイル",
"Already existing files" => "既存のファイル",
"Which files do you want to keep?" => "どちらのファイルを保持しますか？",
"If you select both versions, the copied file will have a number added to its name." => "両方のバージョンを選択した場合は、ファイル名の後ろに数字を追加したファイルのコピーを作成します。",
"Cancel" => "キャンセル",
"Continue" => "続ける",
"(all selected)" => "(すべて選択)",
"({count} selected)" => "({count} 選択)",
"Error loading file exists template" => "既存ファイルのテンプレートの読み込みエラー",
"Very weak password" => "非常に弱いパスワード",
"Weak password" => "弱いパスワード",
"So-so password" => "まずまずのパスワード",
"Good password" => "良好なパスワード",
"Strong password" => "強いパスワード",
"Shared" => "共有中",
"Shared by {owner}" => "{owner} と共有中",
"Shared with {recipients}" => "{recipients} と共有",
"Share" => "共有",
"Error" => "エラー",
"Error while sharing" => "共有でエラー発生",
"Error while unsharing" => "共有解除でエラー発生",
"Error while changing permissions" => "権限変更でエラー発生",
"Shared with you and the group {group} by {owner}" => "あなたと {owner} のグループ {group} で共有中",
"Shared with you by {owner}" => "{owner} と共有中",
"Share with user or group …" => "ユーザーもしくはグループと共有 ...",
"Share link" => "URLで共有",
"The public link will expire no later than {days} days after it is created" => "URLによる共有は、作成してから {days} 日以内に有効期限切れになります",
"By default the public link will expire after {days} days" => "デフォルトの設定では、URLによる共有は {days} 日後に有効期限切れになります",
"Password protect" => "パスワード保護を有効化",
"Choose a password for the public link" => "URLによる共有のパスワードを入力",
"Allow Public Upload" => "アップロードを許可",
"Email link to person" => "メールリンク",
"Send" => "送信",
"Set expiration date" => "有効期限を設定",
"Expiration date" => "有効期限",
"Share via email:" => "メール経由で共有:",
"No people found" => "ユーザーが見つかりません",
"group" => "グループ",
"Resharing is not allowed" => "再共有は許可されていません",
"Shared in {item} with {user}" => "{item} 内で {user} と共有中",
"Unshare" => "共有解除",
"notify by email" => "メールで通知",
"can share" => "共有可",
"can edit" => "編集を許可",
"access control" => "アクセス権限",
"create" => "作成",
"update" => "アップデート",
"delete" => "削除",
"Password protected" => "パスワード保護",
"Error unsetting expiration date" => "有効期限の未設定エラー",
"Error setting expiration date" => "有効期限の設定でエラー発生",
"Sending ..." => "送信中...",
"Email sent" => "メールを送信しました",
"Warning" => "警告",
"The object type is not specified." => "オブジェクトタイプが指定されていません。",
"Enter new" => "新規に入力",
"Delete" => "削除",
"Add" => "追加",
"Edit tags" => "タグを編集",
"Error loading dialog template: {error}" => "メッセージテンプレートの読み込みエラー: {error}",
"No tags selected for deletion." => "削除するタグが選択されていません。",
"Updating {productName} to version {version}, this may take a while." => "{productName} を バージョン {version} に更新しています。しばらくお待ち下さい。",
"Please reload the page." => "ページをリロードしてください。",
"The update was unsuccessful." => "アップデートに失敗しました。",
"The update was successful. Redirecting you to ownCloud now." => "アップデートに成功しました。今すぐownCloudにリダイレクトします。",
"Couldn't reset password because the token is invalid" => "トークンが無効なため、パスワードをリセットできませんでした",
"Couldn't send reset email. Please make sure your username is correct." => "リセットメールを送信できませんでした。ユーザ名が正しいかどうか確認して下さい。",
"Couldn't send reset email because there is no email address for this username. Please contact your administrator." => "このユーザ名に紐付けられたメールアドレスが無いため、リセットメールを送信できませんでした。管理者に問い合わせてください。",
"%s password reset" => "%s パスワードリセット",
"Use the following link to reset your password: {link}" => "パスワードをリセットするには次のリンクをクリックしてください: {link}",
"You will receive a link to reset your password via Email." => "メールでパスワードをリセットするリンクが届きます。",
"Username" => "ユーザー名",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "ファイルが暗号化されています。リカバリキーを有効にしていなかった場合、パスワードをリセットしてからデータを復旧する方法はありません。何をすべきかよくわからないなら、続ける前にまず管理者に連絡しましょう。本当に続けますか？",
"Yes, I really want to reset my password now" => "はい、今すぐパスワードをリセットします。",
"Reset" => "リセット",
"New password" => "新しいパスワードを入力",
"New Password" => "新しいパスワード",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Mac OS X では、サポートされていません。このOSでは、%sは正常に動作しないかもしれません。ご自身の責任においてご利用ください。",
"For the best results, please consider using a GNU/Linux server instead." => "最も良い方法としては、代わりにGNU/Linuxサーバーを利用することをご検討ください。",
"Personal" => "個人",
"Users" => "ユーザー",
"Apps" => "アプリ",
"Admin" => "管理",
"Help" => "ヘルプ",
"Error loading tags" => "タグの読み込みエラー",
"Tag already exists" => "タグはすでに存在します",
"Error deleting tag(s)" => "タグの削除エラー",
"Error tagging" => "タグの付与エラー",
"Error untagging" => "タグの解除エラー",
"Error favoriting" => "お気に入りに追加エラー",
"Error unfavoriting" => "お気に入りから削除エラー",
"Access forbidden" => "アクセスが禁止されています",
"Cloud not found" => "見つかりません",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "こんにちは、\n\n%s があなたと %s を共有したことをお知らせします。\nそれを表示: %s\n",
"The share will expire on %s." => "共有は %s で有効期限が切れます。",
"Cheers!" => "それでは！",
"Security Warning" => "セキュリティ警告",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "あなたのPHPのバージョンには、Null Byte攻撃(CVE-2006-7243)という脆弱性が含まれています。",
"Please update your PHP installation to use %s securely." => "%s を安全に利用するため、インストールされているPHPをアップデートしてください。",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "セキュアな乱数生成器が利用可能ではありません。PHPのOpenSSL拡張を有効にしてください。",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "セキュアな乱数生成器が無い場合、攻撃者がパスワードリセットのトークンを予測してアカウントを乗っ取られる可能性があります。",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => ".htaccess ファイルが動作していないため、おそらくあなたのデータディレクトリもしくはファイルはインターネットからアクセス可能です。",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "サーバーを適正に設定する情報は、こちらの<a href=\"%s\" target=\"_blank\">ドキュメント</a>を参照してください。",
"Create an <strong>admin account</strong>" => "<strong>管理者アカウント</strong>を作成してください",
"Password" => "パスワード",
"Storage & database" => "ストレージとデータベース",
"Data folder" => "データフォルダー",
"Configure the database" => "データベースを設定してください",
"Only %s is available." => "%s のみ有効です。",
"Database user" => "データベースのユーザー名",
"Database password" => "データベースのパスワード",
"Database name" => "データベース名",
"Database tablespace" => "データベースの表領域",
"Database host" => "データベースのホスト名",
"SQLite will be used as database. For larger installations we recommend to change this." => "SQLite をデータベースとして利用します。大規模な運用では、利用しないことをお勧めします。",
"Finish setup" => "セットアップを完了します",
"Finishing …" => "作業を完了しています ...",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "このアプリケーションを使用するにはJavaScriptが必要です。\n<a href=\"http://enable-javascript.com/\" target=\"_blank\">JavaScriptを有効にし</a>、インターフェースを更新してください。 ",
"%s is available. Get more information on how to update." => "%s が利用可能です。アップデート方法について詳細情報を確認してください。",
"Log out" => "ログアウト",
"Automatic logon rejected!" => "自動ログインは拒否されました！",
"If you did not change your password recently, your account may be compromised!" => "最近パスワードを変更していない場合、あなたのアカウントが危険にさらされている可能性があります!",
"Please change your password to secure your account again." => "アカウント保護のため、パスワードを再度変更してください。",
"Server side authentication failed!" => "サーバーサイドの認証に失敗しました！",
"Please contact your administrator." => "管理者に問い合わせてください。",
"Forgot your password? Reset it!" => "パスワードを忘れましたか？リセットします！",
"remember" => "パスワードを保存",
"Log in" => "ログイン",
"Alternative Logins" => "代替ログイン",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "こんにちは、<br><br>%sがあなたと »%s« を共有したことをお知らせします。<br><a href=\"%s\">それを表示</a><br><br>",
"This ownCloud instance is currently in single user mode." => "このownCloudインスタンスは、現在シングルユーザーモードです。",
"This means only administrators can use the instance." => "これは、管理者のみがインスタンスを利用できることを意味しています。",
"Contact your system administrator if this message persists or appeared unexpectedly." => "このメッセージが引き続きもしくは予期せず現れる場合は、システム管理者に連絡してください。",
"Thank you for your patience." => "しばらくお待ちください。",
"%s will be updated to version %s." => "%s はバージョン %s にアップデートされました。",
"The following apps will be disabled:" => "以下のアプリは無効です：",
"The theme %s has been disabled." => "テーマ %s が無効になっています。",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "データベースを確認してください。実行前にconfig フォルダとdata フォルダをバックアップします。",
"Start update" => "アップデートを開始",
"This ownCloud instance is currently being updated, which may take a while." => "この ownCloud インスタンスは現在アップデート中のため、しばらく時間がかかります。",
"Please reload this page after a short time to continue using ownCloud." => "ownCloud を続けて利用するには、しばらくした後でページをリロードしてください。",
"To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" => "大規模なサイトの場合、ブラウザーがタイムアウトする可能性がある為、インストールディレクトリで次のコマンドを実行しても構いません。",
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
